
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">
	
	<xsl:param name="ODMVERSION">1.2</xsl:param>
	<xsl:param name="ADDHYPERLINKSTOMETADATA">true</xsl:param>
	<xsl:param name="ADDHYPERLINKSTOADMINDATA">true</xsl:param>	
	<xsl:param name="FONTSIZE">small</xsl:param>
	<xsl:variable name="TITLE_EMPH">blue</xsl:variable>
	<xsl:variable name="BGCOLOR1">#B8B8B8</xsl:variable>
	<!--xsl:variable name="BGCOLOR1">yellow</xsl:variable-->
	<xsl:variable name="EMPH">blue</xsl:variable>
	<xsl:variable name="TABLEBORDERSIZE">1</xsl:variable>
	<xsl:variable name="PADDING">5</xsl:variable>
	
	<!-- TODO: add ODMDOC ??? in order to find metadata -->
	
	<!-- This stylesheet reads the AuditRecords.xml temporary file -->
	
	<xsl:template match="/">
		<!--xsl:message>start</xsl:message-->
		<html>
		<head> 
			<!--link rel="stylesheet" type="text/css" href="standard.css" title="Style" media="screen"/-->
			<!--link rel="stylesheet" type="text/css" href="general.css" title="Style" media="screen" />
			<style type="text/css">
				p strong { font-family: sans-serif; font-size: 80%; background-color: gray; color: green; }
			</style-->
			<!-- styling for PDF (landscape) -->
			<style type="text/css">
				@page {
   					size: 11.69in 8.27in;  
   					/* font-family: "Comic"; */
   					/* -fs-flow-bottom: my_footer;  */
   					/* table-cell-padding: 5px 5px; */
				}

			</style>
			<!-- HTML styling -->
			<style type="text/css">
				h1,h2,h3,h4,h5 { color:black }
				h3 { color:blue }
				td {
      				background-color: #F7F4E4; 
      				border: 1px solid #9AA7AE;
      				padding: 0.25cm 0.25cm 0.25cm 0.25cm;
      				/* padding-left: 1cm;
      				padding-right: 1cm;
      				padding-top: 1cm;
      				padding-bottom: 1cm; */
    			}
    			td:dt {
    				border: 10px solid #9AA7AE;
    				width: 300px;
    			}
    			body {
     				font-family: "Arial Unicode MS"; 
     				font-size: <xsl:value-of select="$FONTSIZE"/>;
     				-fs-pdf-font-embed: embed;
				} 
			</style>
		</head>
		<body>
			<h2>Simple Statistics for (selected) Audit Records</h2>
			<xsl:apply-templates/>
		</body>
		</html>
		
	</xsl:template>
	
	<xsl:template match="Results">
		<!-- NEW 10.8.2009 -->
		<xsl:call-template name="ShowSelections"/>
	<!--xsl:template match="AuditRecords"-->
		<xsl:call-template name="CountByItemData"/>
		<xsl:call-template name="CountBySubject"/>
		<xsl:call-template name="CountByInvestigator"/>
		<xsl:call-template name="CountBySite"/>
		<xsl:call-template name="CountByUser"/>
		<xsl:call-template name="CountByLocation"/>
	</xsl:template>
	
	<xsl:template name="CountByItemData">
		<xsl:variable name="TOTAL"><xsl:value-of select="count(AuditRecord)"/></xsl:variable>
		<xsl:message>Total number of AuditRecords = <xsl:value-of select="$TOTAL"/></xsl:message>
		<xsl:message>Count by ItemData:</xsl:message>
		<xsl:variable name="STATSBYITEM">
			<xsl:for-each-group select="AuditRecord[@ItemOID]" group-by="@ItemOID">
				<xsl:element name="ITEM">
					<xsl:attribute name="OID"><xsl:value-of select="current-grouping-key()"/></xsl:attribute>
					<xsl:attribute name="NAME"><xsl:value-of select="@ItemName"/></xsl:attribute>
					<xsl:attribute name="COUNT"><xsl:value-of select="count(current-group())"/></xsl:attribute>
					<xsl:attribute name="STUDYOID"><xsl:value-of select="@StudyOID"/></xsl:attribute>
					<xsl:attribute name="METADATAVERSIONOID"><xsl:value-of select="@MetaDataVersionOID"/></xsl:attribute>
				</xsl:element>
			</xsl:for-each-group>
		</xsl:variable>
		<!-- we now have a temporary tree $STATSBYITEM with ITEM elements having an OID and COUNT attribute -->
		<!--xsl:message>STATSBYITEM has <xsl:value-of select="count($STATSBYITEM/*)"/> elements</xsl:message-->
		<!-- transform to HTML -->
		<xsl:call-template name="CreateCountHTMLTable">
			<xsl:with-param name="TOPIC">ItemData point</xsl:with-param>
			<xsl:with-param name="DATASET" select="$STATSBYITEM"/>
			<xsl:with-param name="TOTAL" select="$TOTAL"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- Count by Subject -->
	<xsl:template name="CountBySubject">
		<xsl:variable name="TOTAL"><xsl:value-of select="count(AuditRecord)"/></xsl:variable>
		<xsl:variable name="STATSBYSUBJECT">
			<xsl:for-each-group select="AuditRecord[@SubjectKey]" group-by="@SubjectKey">
				<xsl:element name="SUBJECT">
					<!-- we abuse the OID for a SubjectKey -->
					<xsl:attribute name="OID"><xsl:value-of select="current-grouping-key()"/></xsl:attribute>
					<xsl:attribute name="COUNT"><xsl:value-of select="count(current-group())"/></xsl:attribute>
					<xsl:attribute name="STUDYOID"><xsl:value-of select="@StudyOID"/></xsl:attribute>
					<xsl:attribute name="METADATAVERSIONOID"><xsl:value-of select="@MetaDataVersionOID"/></xsl:attribute>
				</xsl:element>
			</xsl:for-each-group>
		</xsl:variable>
		<xsl:message>Count by Subject <xsl:value-of select="count($STATSBYSUBJECT/*)"/></xsl:message>
		<!-- transform to HTML -->
		<xsl:call-template name="CreateCountHTMLTable">
			<xsl:with-param name="TOPIC">Subject</xsl:with-param>
			<xsl:with-param name="DATASET" select="$STATSBYSUBJECT"/>
			<xsl:with-param name="TOTAL" select="$TOTAL"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="CountByInvestigator">
		<xsl:message>Count by Investigator</xsl:message>
		<xsl:variable name="TOTAL"><xsl:value-of select="count(AuditRecord)"/></xsl:variable>
		<xsl:variable name="STATSBYINVESTIGATOR">
			<xsl:for-each-group select="AuditRecord[@InvestigatorOID]" group-by="@InvestigatorOID">
				<xsl:element name="INVESTIGATOR">
					<xsl:attribute name="OID"><xsl:value-of select="current-grouping-key()"/></xsl:attribute>
					<xsl:attribute name="NAME"><xsl:value-of select="@InvestigatorName"/></xsl:attribute>
					<xsl:attribute name="COUNT"><xsl:value-of select="count(current-group())"/></xsl:attribute>
					<xsl:attribute name="STUDYOID"><xsl:value-of select="@StudyOID"/></xsl:attribute>
					<xsl:attribute name="METADATAVERSIONOID"><xsl:value-of select="@MetaDataVersionOID"/></xsl:attribute>
				</xsl:element>
			</xsl:for-each-group>
		</xsl:variable>
		<!-- transform to HTML -->
		<xsl:call-template name="CreateCountHTMLTable">
			<xsl:with-param name="TOPIC">Investigator</xsl:with-param>
			<xsl:with-param name="DATASET" select="$STATSBYINVESTIGATOR"/>
			<xsl:with-param name="TOTAL" select="$TOTAL"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="CountBySite">
		<xsl:message>Count by Site</xsl:message>
		<xsl:variable name="TOTAL"><xsl:value-of select="count(AuditRecord)"/></xsl:variable>
		<xsl:variable name="STATSBYSITE">
			<xsl:for-each-group select="AuditRecord[@SiteOID]" group-by="@SiteOID">
				<xsl:element name="SITE">
					<xsl:attribute name="OID"><xsl:value-of select="current-grouping-key()"/></xsl:attribute>
					<xsl:attribute name="NAME"><xsl:value-of select="@SiteName"/></xsl:attribute>
					<xsl:attribute name="COUNT"><xsl:value-of select="count(current-group())"/></xsl:attribute>
					<xsl:attribute name="STUDYOID"><xsl:value-of select="@StudyOID"/></xsl:attribute>
					<xsl:attribute name="METADATAVERSIONOID"><xsl:value-of select="@MetaDataVersionOID"/></xsl:attribute>
				</xsl:element>
			</xsl:for-each-group>
		</xsl:variable>
		<!-- transform to HTML -->
		<xsl:call-template name="CreateCountHTMLTable">
			<xsl:with-param name="TOPIC">Site</xsl:with-param>
			<xsl:with-param name="DATASET" select="$STATSBYSITE"/>
			<xsl:with-param name="TOTAL" select="$TOTAL"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="CountByUser">
		<xsl:message>Count by Auditor (User)</xsl:message>
		<xsl:variable name="TOTAL"><xsl:value-of select="count(AuditRecord)"/></xsl:variable>
		<xsl:variable name="STATSBYUSER">
			<xsl:for-each-group select="AuditRecord[UserOID]" group-by="UserOID">
				<xsl:element name="USER">
					<xsl:attribute name="OID"><xsl:value-of select="current-grouping-key()"/></xsl:attribute>
					<xsl:attribute name="NAME"><xsl:value-of select="./UserName"/></xsl:attribute>
					<xsl:attribute name="COUNT"><xsl:value-of select="count(current-group())"/></xsl:attribute>
					<xsl:attribute name="STUDYOID"><xsl:value-of select="@StudyOID"/></xsl:attribute>
					<xsl:attribute name="METADATAVERSIONOID"><xsl:value-of select="@MetaDataVersionOID"/></xsl:attribute>
				</xsl:element>
			</xsl:for-each-group>
		</xsl:variable>
		<!-- transform to HTML -->
		<xsl:call-template name="CreateCountHTMLTable">
			<xsl:with-param name="TOPIC">Auditor (User)</xsl:with-param>
			<xsl:with-param name="DATASET" select="$STATSBYUSER"/>
			<xsl:with-param name="TOTAL" select="$TOTAL"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="CountByLocation">
		<xsl:message>Count by Auditing Location (Location)</xsl:message>
		<xsl:variable name="TOTAL"><xsl:value-of select="count(AuditRecord)"/></xsl:variable>
		<xsl:variable name="STATSBYLOCATION">
			<xsl:for-each-group select="AuditRecord[LocationOID]" group-by="LocationOID">
				<xsl:element name="LOCATION">
					<xsl:attribute name="OID"><xsl:value-of select="current-grouping-key()"/></xsl:attribute>
					<xsl:attribute name="NAME"><xsl:value-of select="./LocationName"/></xsl:attribute>
					<xsl:attribute name="COUNT"><xsl:value-of select="count(current-group())"/></xsl:attribute>
					<xsl:attribute name="STUDYOID"><xsl:value-of select="@StudyOID"/></xsl:attribute>
					<xsl:attribute name="METADATAVERSIONOID"><xsl:value-of select="@MetaDataVersionOID"/></xsl:attribute>
				</xsl:element>
			</xsl:for-each-group>
		</xsl:variable>
		<!-- transform to HTML -->
		<xsl:call-template name="CreateCountHTMLTable">
			<xsl:with-param name="TOPIC">Auditor Location</xsl:with-param>
			<xsl:with-param name="DATASET" select="$STATSBYLOCATION"/>
			<xsl:with-param name="TOTAL" select="$TOTAL"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="CreateCountHTMLTable">
		<xsl:param name="TOPIC"/>
		<xsl:param name="DATASET"></xsl:param> <!-- THIS IS A TREE -->
		<xsl:param name="TOTAL">0</xsl:param>
		<xsl:param name="STUDYOID"></xsl:param>
		<xsl:param name="METADATAVERSIONOID"></xsl:param>
		
		<xsl:message>Topic = <xsl:value-of select="$TOPIC"/></xsl:message>
		<!-- create an XPATH String for hyperlinking -->
		
		<!-- TODO: make list of choices in the selection from the GUI -->
		<h3>Audit Record counts by <xsl:value-of select="$TOPIC"/></h3>
		<p>Total number of Audit Records: <xsl:value-of select="$TOTAL"/></p>
		<table border="{$TABLEBORDERSIZE}" style="border-style:outset">
			<thead>
				<tr>
					<td style="background-color:{$BGCOLOR1}"><xsl:value-of select="$TOPIC"/></td>
					<!-- NOT in case of Count By Subject -->
					<xsl:if test="not($TOPIC = 'Subject')">
						<td style="background-color:{$BGCOLOR1}">Name</td>
					</xsl:if>
					<td style="background-color:{$BGCOLOR1}">Count</td>
					<td style="background-color:{$BGCOLOR1}">Percentage</td>
				</tr>
				<xsl:for-each select="$DATASET/*">
					<xsl:sort select="@COUNT" data-type="number" order="descending"/>
					<xsl:variable name="PERCENTAGE" select="@COUNT div $TOTAL * 100"/>
					<xsl:message><xsl:value-of select="@OID"/> - count = <xsl:value-of select="@COUNT"/> - percentage = <xsl:value-of select="format-number($PERCENTAGE, '#,##0.00')"/></xsl:message>
					<tr>
						<td>
							<xsl:choose>
								<!-- hyperlinks to AdminData -->
								<xsl:when test="$ADDHYPERLINKSTOADMINDATA = 'true' and 
									(starts-with($TOPIC,'Investigator') or starts-with($TOPIC,'Site') or starts-with($TOPIC,'Auditor (User)') or starts-with($TOPIC,'Auditor Location') )">
									<xsl:variable name="HYPERLINK">
										<xsl:if test="starts-with($TOPIC,'Investigator')">find:/*[name()='ODM']/*[name()='AdminData'][@StudyOID='<xsl:value-of select="@STUDYOID"/>']/*[name()='User'][@OID='<xsl:value-of select="@OID"/>']</xsl:if>
										<xsl:if test="starts-with($TOPIC,'Site')">find:/*[name()='ODM']/*[name()='AdminData'][@StudyOID='<xsl:value-of select="@STUDYOID"/>']/*[name()='Location'][@OID='<xsl:value-of select="@OID"/>']</xsl:if>
										<xsl:if test="starts-with($TOPIC,'Auditor (User)')">find:/*[name()='ODM']/*[name()='AdminData'][@StudyOID='<xsl:value-of select="@STUDYOID"/>']/*[name()='User'][@OID='<xsl:value-of select="@OID"/>']</xsl:if>
										<xsl:if test="starts-with($TOPIC,'Auditor Location')">find:/*[name()='ODM']/*[name()='AdminData'][@StudyOID='<xsl:value-of select="@STUDYOID"/>']/*[name()='Location'][@OID='<xsl:value-of select="@OID"/>']</xsl:if>
									</xsl:variable>
									<!-- create the hyperlink -->
									<xsl:element name="a">
										<xsl:attribute name="href"><xsl:value-of select="$HYPERLINK"/></xsl:attribute>
										<xsl:value-of select="@OID"/>
									</xsl:element>
								</xsl:when>
								<!-- hyperlinks to MetaData -->
								<xsl:when test="$ADDHYPERLINKSTOMETADATA = 'true' and starts-with($TOPIC,'ItemData')">
									<xsl:variable name="HYPERLINK">find:/*[name()='ODM']/*[name()='Study'][@OID='<xsl:value-of select="@STUDYOID"/>']/*[name()='MetaDataVersion'][@OID='<xsl:value-of select="@METADATAVERSIONOID"/>']/*[name()='ItemDef'][@OID='<xsl:value-of select="@OID"/>']</xsl:variable>
									<xsl:message>$HYPERLINK = <xsl:value-of select="$HYPERLINK"/></xsl:message>
									<!-- create the hyperlink -->
									<xsl:element name="a">
										<xsl:attribute name="href"><xsl:value-of select="$HYPERLINK"/></xsl:attribute>
										<xsl:value-of select="@OID"/>
									</xsl:element>
								</xsl:when>
								<!-- no hyperlinks -->
								<xsl:otherwise><xsl:value-of select="@OID"/></xsl:otherwise>
							</xsl:choose>
							
						</td>
						<xsl:if test="not($TOPIC = 'Subject')">
							<td><xsl:value-of select="@NAME"/></td>
						</xsl:if>
						<td><xsl:value-of select="@COUNT"/></td>
						<td><xsl:value-of select="format-number($PERCENTAGE, '#,##0.00')"/></td>
					</tr>
				</xsl:for-each>
			</thead>
		</table>
	</xsl:template>
	
	<!-- 10.8.2009: ShowSelections template -->
	<!-- TODO: one way or another using $BGCOLOR1 does not work here -->
	<!-- COPIED FROM ODMAttributes.xsl - TRY TO KEEP IN SYNC ! -->
	<xsl:template name="ShowSelections">
		<xsl:variable name="BGCOLOR1">#B8B8B8</xsl:variable>
		<xsl:for-each select="Selections"><!-- there should be only one -->
			<h3>Your selections:</h3>
			<h4>Studies: <xsl:if test="Selection_Studies[@All='Yes']">All studies:</xsl:if></h4>
			<table border="{$TABLEBORDERSIZE}">
				<xsl:for-each select="Selection_Studies/Selection">
					<tr><td><xsl:value-of select="@OID"/></td></tr>
				</xsl:for-each>
			</table>
			<h4>MetaData Versions: <xsl:if test="Selection_MetaDataVersions[@All='Yes']">All versions: </xsl:if></h4>
			<table border="{$TABLEBORDERSIZE}" style="border-style:outset">
				<tr><td style="background-color:{$BGCOLOR1}">OID</td><td style="background-color:{$BGCOLOR1}">Name</td></tr>
				<xsl:for-each select="Selection_MetaDataVersions/Selection">
					<tr><td><xsl:value-of select="@OID"/></td><td><xsl:value-of select="@Name"/></td></tr>
				</xsl:for-each>
			</table>
			<h4>Sites: <xsl:if test="Selection_Sites[@All='Yes']">All sites: </xsl:if></h4>
			<table border="{$TABLEBORDERSIZE}">
				<tr><td style="background-color:{$BGCOLOR1}">OID</td><td style="background-color:{$BGCOLOR1}">Name</td></tr>
				<xsl:for-each select="Selection_Sites/Selection">
					<tr><td><xsl:value-of select="@OID"/></td><td><xsl:value-of select="@Name"/></td></tr>
				</xsl:for-each>
			</table>
			<h4>Investigators: <xsl:if test="Selection_Investigators[@All='Yes']">All investigators: </xsl:if></h4>
			<table border="{$TABLEBORDERSIZE}">
				<tr><td style="background-color:{$BGCOLOR1}">OID</td><td style="background-color:{$BGCOLOR1}">Name</td></tr>
				<xsl:for-each select="Selection_Investigators/Selection">
					<tr><td><xsl:value-of select="@OID"/></td><td><xsl:value-of select="@Name"/></td></tr>
				</xsl:for-each>
			</table>
			<xsl:if test="Selection_Auditors">
				<h4>Auditors: <xsl:if test="Selection_Auditors[@All='Yes']">All auditors: </xsl:if></h4>
				<table border="{$TABLEBORDERSIZE}">
				<tr><td style="background-color:{$BGCOLOR1}">OID</td><td style="background-color:{$BGCOLOR1}">Name</td></tr>
				<xsl:for-each select="Selection_Auditors/Selection">
					<tr><td><xsl:value-of select="@OID"/></td><td><xsl:value-of select="@Name"/></td></tr>
				</xsl:for-each>
				</table>
			</xsl:if>
			<xsl:if test="Selection_AuditLocations">
				<h4>Audit Locations: <xsl:if test="Selection_AuditLocations[@All='Yes']">All audit locations: </xsl:if></h4>
				<table border="{$TABLEBORDERSIZE}">
				<tr><td style="background-color:{$BGCOLOR1}">OID</td><td style="background-color:{$BGCOLOR1}">Name</td></tr>
				<xsl:for-each select="Selection_AuditLocations/Selection">
					<tr><td><xsl:value-of select="@OID"/></td><td><xsl:value-of select="@Name"/></td></tr>
				</xsl:for-each>
				</table>
			</xsl:if>
			<!-- Subjects - only when NOT all subjects have been selected, give a listing -->
			<xsl:if test="Selection_Subjects">
				<h4>Subjects: <xsl:if test="Selection_Subjects[@All='Yes']"> <b>ALL</b> subjects for this study/studies</xsl:if></h4>
				<!-- not all subbjects have been selected, give a list -->
				<xsl:if test="not(Selection_Subjects[@All='Yes'])">
					<xsl:variable name="NUMBER_OF_SUBJECTS"><xsl:value-of select="count(Selection_Subjects/Selection)"/></xsl:variable>
					<xsl:message>Number of subjects = <xsl:value-of select="$NUMBER_OF_SUBJECTS"/></xsl:message>
					<xsl:variable name="NUMBER_OF_COLUMNS">8</xsl:variable>
					<xsl:variable name="NUMBER_OF_ROWS" select="ceiling($NUMBER_OF_SUBJECTS div $NUMBER_OF_COLUMNS)"/>
					<xsl:message>Number of rows = <xsl:value-of select="$NUMBER_OF_ROWS"/></xsl:message>
					<table>
						<xsl:for-each select="Selection_Subjects/Selection">
							<xsl:variable name="POSITION" select="position()"/>
							<xsl:choose>
								<xsl:when test="$POSITION = 1 or (($POSITION - 1) mod $NUMBER_OF_COLUMNS = 0)">
									<xsl:element name="tr"/><td><xsl:value-of select="@OID"/></td>
								</xsl:when>
								<xsl:otherwise>
									<td><xsl:value-of select="@OID"/></td>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</table>
				</xsl:if>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
</xsl:stylesheet>