
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0">
	
	<xsl:output method="xml" indent="yes"/>
	<xsl:template match="/">
		<xsl:message>starting</xsl:message>
		<xsl:variable name="AuditRecords">
			<!-- TODO: separate AuditRecords in ReferenceData -->
			<xsl:for-each select="//*[name()='ItemData'][./*[name()='AuditRecord'] or ../*[name()='AuditRecord'] or ../../*[name()='AuditRecord'] or ../../../*[name()='AuditRecord']]">
				<xsl:variable name="ITEMOID" select="@ItemOID"/>
				<xsl:variable name="ITEMDATAVALUE" select="@Value"/>
				<xsl:variable name="SUBJECTKEY" select="../../../../@SubjectKey"/>
				<xsl:for-each select="../../../*[name()='AuditRecord']">
					<xsl:message>Level StudyEventData - OID = <xsl:value-of select="../@StudyEventOID"/></xsl:message>
					<xsl:element name="AuditRecord">
						<xsl:copy-of select="@*"/>
						<xsl:attribute name="ItemOID"><xsl:value-of select="$ITEMOID"/></xsl:attribute>
						<xsl:attribute name="SubjectKey"><xsl:value-of select="$SUBJECTKEY"/></xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="$ITEMDATAVALUE"/></xsl:attribute>
						<xsl:for-each select="./*"><xsl:call-template name="COPY"><xsl:with-param name="CONTENTS" select="."/></xsl:call-template></xsl:for-each>
					</xsl:element>
				</xsl:for-each>
				<xsl:for-each select="../../*[name()='AuditRecord']">
					<xsl:message>Level FormData - OID = <xsl:value-of select="../@FormOID"/></xsl:message>
					<xsl:element name="AuditRecord">
						<xsl:copy-of select="@*"/>
						<xsl:attribute name="ItemOID"><xsl:value-of select="$ITEMOID"/></xsl:attribute>
						<xsl:attribute name="SubjectKey"><xsl:value-of select="$SUBJECTKEY"/></xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="$ITEMDATAVALUE"/></xsl:attribute>
						<xsl:for-each select="./*"><xsl:call-template name="COPY"><xsl:with-param name="CONTENTS" select="."/></xsl:call-template></xsl:for-each>
					</xsl:element>
				</xsl:for-each>
				<xsl:for-each select="../*[name()='AuditRecord']">
					<xsl:message>Level ItemGroupData - OID = <xsl:value-of select="../@ItemGroupOID"/></xsl:message>
					<xsl:element name="AuditRecord">
						<xsl:copy-of select="@*"/>
						<xsl:attribute name="ItemOID"><xsl:value-of select="$ITEMOID"/></xsl:attribute>
						<xsl:attribute name="SubjectKey"><xsl:value-of select="$SUBJECTKEY"/></xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="$ITEMDATAVALUE"/></xsl:attribute>
						<xsl:for-each select="./*"><xsl:call-template name="COPY"><xsl:with-param name="CONTENTS" select="."/></xsl:call-template></xsl:for-each>
					</xsl:element>
				</xsl:for-each>
				<xsl:for-each select="*[name()='AuditRecord']">
					<xsl:message>Level ItemData - OID = <xsl:value-of select="../@ItemOID"/></xsl:message>
					<xsl:element name="AuditRecord">
						<xsl:copy-of select="@*"/>
						<xsl:attribute name="ItemOID"><xsl:value-of select="$ITEMOID"/></xsl:attribute>
						<xsl:attribute name="SubjectKey"><xsl:value-of select="$SUBJECTKEY"/></xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="$ITEMDATAVALUE"/></xsl:attribute>
						<xsl:for-each select="./*"><xsl:call-template name="COPY"><xsl:with-param name="CONTENTS" select="."/></xsl:call-template></xsl:for-each>
					</xsl:element>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:variable>
		<!-- group by ItemOID -->
		<xsl:variable name="AuditRecords_grouped">
			<!-- recursive grouping: first by SubjectKey, and then (within each Subject) by ItemOID -->
			<xsl:for-each-group select="$AuditRecords/AuditRecord" group-by="@SubjectKey">
				<xsl:message>Treating SubjectKey = <xsl:value-of select="@SubjectKey"/></xsl:message>
				<xsl:for-each-group select="current-group()" group-by="@ItemOID">
					<xsl:message><xsl:value-of select="@ItemOID"/></xsl:message>
					<xsl:for-each select="current-group()">
						<xsl:call-template name="COPY"><xsl:with-param name="CONTENTS" select="."/></xsl:call-template>
					</xsl:for-each>
				</xsl:for-each-group>
			</xsl:for-each-group>
		</xsl:variable>
		<!-- print -->
		<xsl:element name="AuditRecords">
			<!--xsl:for-each select="$AuditRecords/*"><xsl:copy-of select="."/></xsl:for-each-->
			<xsl:for-each select="$AuditRecords_grouped/AuditRecord">
				<xsl:call-template name="COPY"><xsl:with-param name="CONTENTS" select="."/></xsl:call-template>
			</xsl:for-each>
		</xsl:element>
	</xsl:template>
	
	<!-- recursive copying, removing the namespace -->
	<xsl:template name="COPY">
		<xsl:param name="CONTENTS"/>
		<xsl:variable name="NAME" select="name($CONTENTS)"/>
		<xsl:element name="{$NAME}">
			<xsl:copy-of select="@*"/>
			<xsl:for-each select="./*">
				<xsl:call-template name="COPY">
					<xsl:with-param name="CONTENTS" select="."/>
				</xsl:call-template>
			</xsl:for-each>
			<!-- text content -->
			<xsl:value-of select="text()"/>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>